==> InfiniTec.Exchange_0.96_Source.zip: ContactEmailAddress.cs <==
using System;
using System.Collections.Generic;
using System.Text;
using System.Diagnostics;
using InfiniTec.Exchange.WebDav;

namespace InfiniTec.Exchange
{
    /// <summary>
    /// This class defines an email address used in contact items.
    /// </summary>
    public class ContactEmailAddress : EmailAddress, ICollectionEntry<EmailAddressIdentifier>
    {
        private EmailAddressIdentifier _AddressIdentifier;
        private TypedItemBase _Item;

        /// <summary>
        /// Gets the address identifier.
        /// </summary>
        /// <value>The address identifier.</value>
        public EmailAddressIdentifier AddressIdentifier
        {
            [DebuggerStepThrough]
            get { return _AddressIdentifier; }
        }

        /// <summary>
        /// Initializes a new instance of the <see cref="ContactEmailAddress"/> class.
        /// </summary>
        /// <param name="addressIdentifier">The address identifier.</param>
        /// <param name="displayName">The display name.</param>
        /// <param name="address">The address.</param>
        public ContactEmailAddress(EmailAddressIdentifier addressIdentifier, string displayName, string address):
            base(address,address)
        {
            _AddressIdentifier = addressIdentifier;
        }

        internal ContactEmailAddress(EmailAddressIdentifier addressType, TypedItemBase item): base(null, null)
        {
            _Item = item;
            _AddressIdentifier = addressType;

            switch (AddressIdentifier)
            {
                case EmailAddressIdentifier.EmailAddress1:
                    DisplayName = _Item.GetPropertyValue<string>(NamedProperties.Contact.Email1DisplayName);
                    Address = _Item.GetPropertyValue<string>(NamedProperties.Contact.Email1EmailAddress);
                    break;
                case EmailAddressIdentifier.EmailAddress2:
                    DisplayName = _Item.GetPropertyValue<string>(NamedProperties.Contact.Email2DisplayName);
                    Address = _Item.GetPropertyValue<string>(NamedProperties.Contact.Email2EmailAddress);
                    break;
                case EmailAddressIdentifier.EmailAddress3:
                    DisplayName = _Item.GetPropertyValue<string>(NamedProperties.Contact.Email3DisplayName);
                    Address = _Item.GetPropertyValue<string>(NamedProperties.Contact.Email3EmailAddress);
                    break;
                default:
                    throw new NotSupportedException("The specified address type is not supported");
            }
        }
        #region ICollectionEntry<EmailAddressType> Members

        void ICollectionEntry<EmailAddressIdentifier>.SetItem(TypedItemBase item)
        {
            _Item = item;
        }

        void ICollectionEntry<EmailAddressIdentifier>.Save()
        {
            switch (AddressIdentifier)
            {
                case EmailAddressIdentifier.EmailAddress1:
                    _Item.SetPropertyValue<string>(NamedProperties.Contact.Email1DisplayName, DisplayName);
                    _Item.SetPropertyValue<string>(NamedProperties.Contact.Email1EmailAddress, Address);
                    break;
                case EmailAddressIdentifier.EmailAddress2:
                    _Item.SetPropertyValue<string>(NamedProperties.Contact.Email2DisplayName, DisplayName);
                    _Item.SetPropertyValue<string>(NamedProperties.Contact.Email2EmailAddress, Address);
                    break;
                case EmailAddressIdentifier.EmailAddress3:
                    _Item.SetPropertyValue<string>(NamedProperties.Contact.Email3DisplayName, DisplayName);
                    _Item.SetPropertyValue<string>(NamedProperties.Contact.Email3EmailAddress, Address);
                    break;
                default:
                    throw new NotSupportedException("The specified address type is not supported");
            }

        }

        void ICollectionEntry<EmailAddressIdentifier>.Delete()
        {
            switch (AddressIdentifier)
            {
                case EmailAddressIdentifier.EmailAddress1:
                    _Item.SetPropertyValue<string>(NamedProperties.Contact.Email1DisplayName, null);
                    _Item.SetPropertyValue<string>(NamedProperties.Contact.Email1EmailAddress, null);
                    break;
                case EmailAddressIdentifier.EmailAddress2:
                    _Item.SetPropertyValue<string>(NamedProperties.Contact.Email2DisplayName, null);
                    _Item.SetPropertyValue<string>(NamedProperties.Contact.Email2EmailAddress, null);
                    break;
                case EmailAddressIdentifier.EmailAddress3:
                    _Item.SetPropertyValue<string>(NamedProperties.Contact.Email3DisplayName, null);
                    _Item.SetPropertyValue<string>(NamedProperties.Contact.Email3EmailAddress, null);
                    break;
                default:
                    throw new NotSupportedException("The specified address type is not supported");
            }
        }

        EmailAddressIdentifier ICollectionEntry<EmailAddressIdentifier>.GetKey()
        {
            return AddressIdentifier;
        }

        #endregion
        
    }
}

==> InfiniTec.Exchange_0.97_Source.zip: ContactEmailAddress.cs <==
using System;
using System.Collections.Generic;
using System.Text;
using System.Diagnostics;
using InfiniTec.Exchange.WebDav;

namespace InfiniTec.Exchange
{
    /// <summary>
    /// This class defines an email address used in contact items.
    /// </summary>
    public class ContactEmailAddress : EmailAddress, ICollectionEntry<EmailAddressIdentifier>
    {
        private EmailAddressIdentifier _AddressIdentifier;
        private Item _Item;

        /// <summary>
        /// Gets the address identifier.
        /// </summary>
        /// <value>The address identifier.</value>
        public EmailAddressIdentifier AddressIdentifier
        {
            [DebuggerStepThrough]
            get { return _AddressIdentifier; }
        }

        /// <summary>
        /// Initializes a new instance of the <see cref="ContactEmailAddress"/> class.
        /// </summary>
        /// <param name="addressIdentifier">The address identifier.</param>
        /// <param name="displayName">The display name.</param>
        /// <param name="address">The address.</param>
        public ContactEmailAddress(EmailAddressIdentifier addressIdentifier, string displayName, string address):
            base(address,address)
        {
            _AddressIdentifier = addressIdentifier;
        }

        internal ContactEmailAddress(EmailAddressIdentifier addressType, Item item): base(null, null)
        {
            _Item = item;
            _AddressIdentifier = addressType;

            switch (AddressIdentifier)
            {
                case EmailAddressIdentifier.EmailAddress1:
                    DisplayName = _Item.GetPropertyValue<string>(NamedProperties.Contact.Email1DisplayName);
                    Address = _Item.GetPropertyValue<string>(NamedProperties.Contact.Email1EmailAddress);
                    break;
                case EmailAddressIdentifier.EmailAddress2:
                    DisplayName = _Item.GetPropertyValue<string>(NamedProperties.Contact.Email2DisplayName);
                    Address = _Item.GetPropertyValue<string>(NamedProperties.Contact.Email2EmailAddress);
                    break;
                case EmailAddressIdentifier.EmailAddress3:
                    DisplayName = _Item.GetPropertyValue<string>(NamedProperties.Contact.Email3DisplayName);
                    Address = _Item.GetPropertyValue<string>(NamedProperties.Contact.Email3EmailAddress);
                    break;
                default:
                    throw new NotSupportedException("The specified address type is not supported");
            }
        }
        #region ICollectionEntry<EmailAddressType> Members

        void ICollectionEntry<EmailAddressIdentifier>.SetItem(Item item)
        {
            _Item = item;
        }

        void ICollectionEntry<EmailAddressIdentifier>.Save()
        {
            switch (AddressIdentifier)
            {
                case EmailAddressIdentifier.EmailAddress1:
                    _Item.SetPropertyValue<string>(NamedProperties.Contact.Email1DisplayName, DisplayName);
                    _Item.SetPropertyValue<string>(NamedProperties.Contact.Email1EmailAddress, Address);
                    break;
                case EmailAddressIdentifier.EmailAddress2:
                    _Item.SetPropertyValue<string>(NamedProperties.Contact.Email2DisplayName, DisplayName);
                    _Item.SetPropertyValue<string>(NamedProperties.Contact.Email2EmailAddress, Address);
                    break;
                case EmailAddressIdentifier.EmailAddress3:
                    _Item.SetPropertyValue<string>(NamedProperties.Contact.Email3DisplayName, DisplayName);
                    _Item.SetPropertyValue<string>(NamedProperties.Contact.Email3EmailAddress, Address);
                    break;
                default:
                    throw new NotSupportedException("The specified address type is not supported");
            }

        }

        void ICollectionEntry<EmailAddressIdentifier>.Delete()
        {
            switch (AddressIdentifier)
            {
                case EmailAddressIdentifier.EmailAddress1:
                    _Item.SetPropertyValue<string>(NamedProperties.Contact.Email1DisplayName, null);
                    _Item.SetPropertyValue<string>(NamedProperties.Contact.Email1EmailAddress, null);
                    break;
                case EmailAddressIdentifier.EmailAddress2:
                    _Item.SetPropertyValue<string>(NamedProperties.Contact.Email2DisplayName, null);
                    _Item.SetPropertyValue<string>(NamedProperties.Contact.Email2EmailAddress, null);
                    break;
                case EmailAddressIdentifier.EmailAddress3:
                    _Item.SetPropertyValue<string>(NamedProperties.Contact.Email3DisplayName, null);
                    _Item.SetPropertyValue<string>(NamedProperties.Contact.Email3EmailAddress, null);
                    break;
                default:
                    throw new NotSupportedException("The specified address type is not supported");
            }
        }

        EmailAddressIdentifier ICollectionEntry<EmailAddressIdentifier>.GetKey()
        {
            return AddressIdentifier;
        }

        #endregion
        
    }
}
